pub enum BackpressurePolicy {
Reject,
DropOldestPerTenant,
DropNewestPerTenant,
Timeout {
wait: Duration,
},
}Expand description
Behavior when enqueue capacity limits are hit.
Variants
Reject
Reject enqueue requests when limits are exceeded.
DropOldestPerTenant
Drop the oldest task from the same tenant and enqueue the new task.
DropNewestPerTenant
Drop the newest task from the same tenant and enqueue the new task.
Timeout
Wait for capacity up to wait, otherwise reject with timeout.