pub struct AsyncReceiver<T> { /* private fields */ }Expand description
Receiver-style async facade over scheduler dequeue.
Implementations
Sourceimpl<T> AsyncReceiver<T>
impl<T> AsyncReceiver<T>
Sourcepub fn new(scheduler: AsyncScheduler<T>) -> Self
pub fn new(scheduler: AsyncScheduler<T>) -> Self
Creates a new receiver facade.
Sourceimpl<T: Send + 'static> AsyncReceiver<T>
impl<T: Send + 'static> AsyncReceiver<T>
Sourcepub async fn recv(&self) -> Option<DequeueItem<T>>
pub async fn recv(&self) -> Option<DequeueItem<T>>
Waits for the next task, returning None once scheduler closes.
Sourcepub fn new_worker(
scheduler: AsyncScheduler<T>,
buffer: usize,
) -> AsyncWorkerReceiver<T>
pub fn new_worker( scheduler: AsyncScheduler<T>, buffer: usize, ) -> AsyncWorkerReceiver<T>
Creates a receiver powered by a dedicated dequeue worker thread.