AsyncWorkerReceiver

Struct AsyncWorkerReceiver 

pub struct AsyncWorkerReceiver<T> { /* private fields */ }
Receiver/stream adapter backed by a dedicated dequeue worker thread.

Implementations

Source

impl<T: Send + 'static> AsyncWorkerReceiver<T>

pub fn new(scheduler: AsyncScheduler<T>, buffer: usize) -> Self

Creates a new worker-backed receiver.

pub async fn recv(&mut self) -> Option<DequeueItem<T>>

Waits for the next task, returning None once the worker stops.